import * as Sentry from '@sentry/browser';
import { Integrations } from '@sentry/tracing';
import 'bootstrap/js/dist/dropdown';
import 'bootstrap/js/dist/modal';
import 'bootstrap/js/dist/popover';
import 'bootstrap/js/dist/button';
import '@fortawesome/fontawesome-free/js/all';
import 'easy-autocomplete';

import './kmg-interactive';
import {
  setAuth, setSid, addTGObject, getMimeClass, view, links, allowDrop, drop, log, publish
} from './publish-gui';
import './edition';
import './edition-nav';
import './register';
import './search';

const $ = require('jquery');
const jQuery = require('jquery');

Sentry.init({
  dsn: 'https://968b102ddf9b46b38b6c54fa8f1b18e0@dev2.discuss-data.net/7',
  integrations: [
    new Integrations.BrowserTracing(),
  ],

  tracesSampleRate: 1.0,
});

/* PUBLISH */
/* add functions to the global scope so that they can be called by the TGLab plugin */
window.setAuth = setAuth;
window.setSid = setSid;
window.addTGObject = addTGObject;
window.getMimeClass = getMimeClass;
window.view = view;
window.links = links;
window.allowDrop = allowDrop;
window.drop = drop;
window.log = log;
window.publish = publish;


//* * jQuery Scroll to Top Control script- (c) Dynamic Drive DHTML code library: http://www.dynamicdrive.com.
//* * Available/ usage terms at http://www.dynamicdrive.com (March 30th, 09')
//* * v1.1 (April 7th, 09'):
//* * 1) Adds ability to scroll to an absolute position (from top of page) or specific element on the page instead.
//* * 2) Fixes scroll animation not working in Opera.

const scrolltotop = {
  // startline: Integer. Number of pixels from top of doc scrollbar is scrolled before showing control
  // scrollto: Keyword (Integer, or "Scroll_to_Element_ID"). How far to scroll document up when control is clicked on (0=top).
  setting: {
    startline: 100, scrollto: 0, scrollduration: 1000, fadeduration: [500, 100],
  },
  controlHTML: '<i class="fas fa-chevron-up backtotop" style="width:45px;height:45px;padding-left:12px;padding-right:12px"></i>', // HTML for control, which is auto wrapped in DIV w/ ID="topcontrol"
  controlattrs: { offsetx: 12, offsety: 12 }, // offset of control relative to right/ bottom of window corner
  anchorkeyword: '#top', // Enter href value of HTML anchors on the page that should also act as "Scroll Up" links

  state: { isvisible: false, shouldvisible: false },

  scrollup() {
    if (!this.cssfixedsupport) // if control is positioned using JavaScript
    { this.$control.css({ opacity: 0 }); } // hide control immediately after clicking it
    let dest = isNaN(this.setting.scrollto) ? this.setting.scrollto : parseInt(this.setting.scrollto);
    if (typeof dest === 'string' && jQuery(`#${dest}`).length == 1) // check element set by string exists
    { dest = jQuery(`#${dest}`).offset().top; } else dest = 0;
    this.$body.animate({ scrollTop: dest }, this.setting.scrollduration);
  },

  keepfixed() {
    const $window = jQuery(window);
    const controlx = $window.scrollLeft() + $window.width() - this.$control.width() - this.controlattrs.offsetx;
    const controly = $window.scrollTop() + $window.height() - this.$control.height() - this.controlattrs.offsety;
    this.$control.css({ left: `${controlx}px`, top: `${controly}px` });
  },

  togglecontrol() {
    const scrolltop = jQuery(window).scrollTop();
    if (!this.cssfixedsupport) this.keepfixed();
    this.state.shouldvisible = (scrolltop >= this.setting.startline);
    if (this.state.shouldvisible && !this.state.isvisible) {
      this.$control.stop().animate({ opacity: 1 }, this.setting.fadeduration[0]);
      this.state.isvisible = true;
    } else if (this.state.shouldvisible == false && this.state.isvisible) {
      this.$control.stop().animate({ opacity: 0 }, this.setting.fadeduration[1]);
      this.state.isvisible = false;
    }
  },

  init() {
    jQuery(document).ready(($) => {
      const mainobj = scrolltotop;
      const iebrws = document.all;
      mainobj.cssfixedsupport = !iebrws || iebrws && document.compatMode == 'CSS1Compat' && window.XMLHttpRequest; // not IE or IE7+ browsers in standards mode
      mainobj.$body = (window.opera) ? (document.compatMode == 'CSS1Compat' ? $('html') : $('body')) : $('html,body');
      mainobj.$control = $(`<div id="topcontrol">${mainobj.controlHTML}</div>`)
        .css({
          position: mainobj.cssfixedsupport ? 'fixed' : 'absolute', bottom: mainobj.controlattrs.offsety, right: mainobj.controlattrs.offsetx, opacity: 0, cursor: 'pointer',
        })
        .attr({ title: '' })
        .on('click', () => { mainobj.scrollup(); return false; })
        .appendTo('body');
      if (document.all && !window.XMLHttpRequest && mainobj.$control.text() != '') // loose check for IE6 and below, plus whether control contains any text
      { mainobj.$control.css({ width: mainobj.$control.width() }); } // IE6- seems to require an explicit width on a DIV containing text
      mainobj.togglecontrol();
      $(`a[href="${mainobj.anchorkeyword}"]`).on('click', () => {
        mainobj.scrollup();
        return false;
      });
      $(window).bind('scroll resize', (e) => {
        mainobj.togglecontrol();
      });
    });
  },
};

scrolltotop.init();

/**
 * Functionality to switch between light and dark theme. Stores system preference
 * and chosen mode in local storage.
 */
const darkmodeBtn = document.querySelector('.darktheme-btn');
const prefersDarkTheme = window.matchMedia('(prefers-color-scheme: dark)');

const currentTheme = localStorage.getItem('theme');
if (currentTheme == 'dark') {
  document.body.classList.toggle('dark-theme');
} else if (currentTheme == 'light') {
  document.body.classList.toggle('light-theme');
}

darkmodeBtn.addEventListener('click', function () {
  document.body.classList.toggle('dark-theme');
  document.body.classList.toggle('light-theme');
  if (prefersDarkTheme.matches) {
    var theme = document.body.classList.contains('light-theme')
      ? 'light'
      : 'dark';
  } else {
    var theme = document.body.classList.contains('dark-theme')
      ? 'dark'
      : 'light';
  }
  localStorage.setItem('theme', theme);
});