xquery version "3.1";

(: ~
 : This module contains unit tests for kmg-transform.xqm.
 :
 : @author Simon Sendler
 : @since 1.3.0
 :)

module namespace tsttransf="http://mollenhauer-edition.de/ns/tsttransf";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace html="http://www.w3.org/1999/xhtml";
declare default element namespace "http://www.w3.org/1999/xhtml";

import module namespace test="http://exist-db.org/xquery/xqsuite" at "resource:org/exist/xquery/lib/xqsuite/xqsuite.xql";
import module namespace transformKMG="http://mollenhauer-edition.de/ns/transform" at "../modules/kmg/transform.xqm";

declare
    %test:assertExists
    %test:assertEquals("test string")
function tsttransf:text()
as text() {
    let $node := <tei:ab>test string</tei:ab>
    return
        transformKMG:transform($node/text(), "test", "test")
};

declare
    %test:assertXPath("$result[ local-name(.) = 'li' and @id = 'Liste1' and @class = 'list-item' ]")
    %test:assertXPath("$result/*[1][ @class = 'list-item__label' ]")
function tsttransf:list()
as element(li)+
{
    let $element := transformKMG:transform(local:sample()//tei:list, "test", "test")
    return
        $element/li[1]
};

declare function local:transform-rdgs()
as element()+
{
    local:sample()//tei:rdg ! transformKMG:make-reading(., "test", "test")
};

declare
    %test:assertXPath("$result[ local-name(.) = 'span' and contains(@class, 'rdg-digital') ]")
function tsttransf:rdgs-rdg()
as element(span)
{
    let $rdgs := local:transform-rdgs()
    return
        $rdgs[1]
};

declare
    %test:assertXPath("$result[ local-name(.) = 'path' and contains(@class, 'rdg-digital-path') ]")
function tsttransf:rdgs-path()
as element(path)
{
    let $rdgs := local:transform-rdgs()
    return
        $rdgs[2]
};

declare
    %test:assertTrue
function tsttransf:rdgs-wit()
as xs:boolean
{
    let $rdgs := local:transform-rdgs()
    return
        $rdgs[3]/@wits eq 'b'
};

declare
    %test:assertEquals("6")
function tsttransf:rdgs-exclude-strucural-variance()
as xs:integer
{
    let $rdgs := local:transform-rdgs()
    let $no := count($rdgs)
    return
        $no
};

declare
    %test:assertTrue
function tsttransf:find-corresp-node()
as xs:boolean
{
    let $id := "Liste1"
    let $model := local:sample()//tei:item[ @xml:id = $id ]
    let $copyOf := "#" || $id
    let $element := local:sample()//tei:item[ @copyOf = $copyOf ]
    let $result := transformKMG:find-corresp-node($element, $copyOf)
    return
        $result/text() eq $model/text()
};

declare
    %test:assertExists
function tsttransf:join-branches()
as element(item)
{
    let $element := local:sample()//tei:join
    let $result := transformKMG:resolve-join($element)
    return
        $result
};

declare
    %test:assertTrue
function tsttransf:copy-node()
as xs:boolean
{
    let $id := "Liste1"
    let $model := local:sample()//tei:item[ @xml:id = $id ]
    let $element := local:sample()//tei:item[ @copyOf = "#" || $id ]
    let $result := transformKMG:transform($element, "test", "test")
    return
        $result eq $model
};

declare
    %test:assertXPath("starts-with($result, '&#x201E;')")
function tsttransf:quote()
as element(q)
{
    transformKMG:transform(local:sample()//tei:q, "test", "test")
};

declare
    %test:args("commentary") %test:assertExists
    %test:args("digital") %test:assertEmpty
    %test:args("single") %test:assertEmpty
    %test:args("test") %test:assertEmpty
function tsttransf:modes($mode as xs:string)
as xs:string?
{
    transformKMG:transform(local:sample()//tei:text, "test", $mode)
};

declare
    %test:assertXPath("$result/@class = 'error-message' ")
function tsttransf:error()
as element(span)
{
    let $invalid := 
        <name xmlns="http://www.tei-c.org/ns/1.0">
            Testname that fails transformation for missing type-Attribute
        </name>
    return
        transformKMG:transform($invalid, "test", "test")
};

declare function local:sample()
as element()
{
    <body xmlns="http://www.tei-c.org/ns/1.0">
        <text type="commentary">
            Commentary
        </text>
        <app>
            <lem wit="#a">
                <list type="numbered" xml:id="liste1">
                    <label type="list">1</label>
                    <item xml:id="Liste1">
                        Ein Mädchen kauft sich eine neue Lampe, die ihrem persönlichen Geschmack in besonderer Weise entspricht. Sie erlebt dann aber, daß sie eines Tages genau die gleiche bei Bekannten findet, das geschieht öfter, und schließlich sieht sie sie in Schaufenstern und wird sich der massenweisen Produktion dieses Artikels bewußt, der ihr ursprünglich als ein ganz individuelles, ihren persönlichen Bedürfnissen entsprechendes Exemplar erschienen war. Der Spaß ist ihr verdorben. Sie fühlt sich hintergangen, irgendwie betrogen, sie ist verärgert und äußert das. Ich erkläre daraufhin, daß das typisch bürgerlich gedacht und gefühlt sei. Sie erwartet nämlich von den produzierten Dingen, daß sie imstande seien, als ihre persönliche Ausdruckswelt zu fungieren, ihr persönliches Bedürfnis nach einer individuellen Innerlichkeit und deren Ausdruck zu befriedigen. Sie stellt damit an die moderne Gesellschaft unerfüllbare Anforderungen; ein Serienprodukt kann das seinem Wesen nach als einzelnes Ding nicht mehr leisten. Das Mädchen resigniert und bastelt sich in Zukunft ihre Lampe selbst.
                    </item>
                    <label type="list">2</label>
                    <item xml:id="Liste2">
                        Ein Kind wächst in einer Familie auf, die einen kultivierten und sehr klaren, sich in alle Lebensbereiche erstreckenden Stil hat. Die Hausmusikpflege ist dieser Familie genauso eigentümlich wie – sagen wir
                        <app>
                            <lem wit="#a"/>
                            <rdg wit="#b">–</rdg>
                        </app>
                            die Wohlerzogenheit der Kinder und die religiöse Bindung. In allem aber drückt sich dieser einheitliche Familienstil aus. Der
                        <app>
                            <lem wit="#a">Jugendliche</lem>
                            <rdg wit="#b">
                            <choice>
                                <sic>jugendliche</sic>
                                <corr resp="#AnH" type="KMG">Jugendliche</corr>
                            </choice>
                            </rdg>
                        </app>
                        verläßt diese Familie und erlebt, daß er die gewonnenen Erfahrungen nicht übertragen kann, daß die widersprechenden Erfahrungen, die er nun in der Gesellschaft macht, vor der Wahlurne, im Berufsleben, im Kino, mit moderner Kunst, daß diese mit seinem Ich, so wie es in der Familie gebildet worden ist, nicht in Einklang zu bringen sind. Er er
                        <pb edRef="#a" n="6"/>
                        fährt, soweit er in die moderne Gesellschaft hineinzuwachsen versucht, daß die in der Familie erworbenen Fähigkeiten und Wertvorstellungen offenbar nur dort gelten, daß die Familie offenbar ein
                        <app>
                            <lem wit="#a">isoliertes</lem>
                            <rdg wit="#b">
                            <choice>
                                <sic>Isoliertes</sic>
                                <corr resp="#AnH" type="KMG">isoliertes</corr>
                            </choice>
                            </rdg>
                        </app>
                        Inseldasein in einer ganz anderen Welt führt. Er versucht sich dem Neuen anzupassen; dieser Versuch mißlingt, weil er dieses Anpassen nicht gelernt hat; er distanziert sich von der Familie, randaliert und verwahrlost. Das Jugendamt schickt ihn in ein Heim, das nach dem
                        <q rend="double">Familienprinzip</q>
                        organisiert ist.
                    </item>
                    <label type="list">5</label>
                    <item>
                    <p xml:id="Liste5">
                        Erwachsene und Jugendliche sitzen zusammen im Kino und sehen einen Durchschnittsfilm. Die Jugendlichen äußern laute Zwischenbemerkungen, bisweilen ironische Beifallsrufe, kommentierendes Gelächter. Die Erwachsenen sind empört, sie sind beleidigt, in ihrer Faszination gestört zu werden; aber sie erklären diesen Film für jugendgefährdend.
                    </p>
                    <p xml:id="Liste6">
                        Man wird zugeben müssen, daß die in jedem Fall gezogene Konsequenz nicht nur heute möglich, sondern sogar nicht gerade selten ist. Ich behaupte nun, daß diese Konsequenzen auf einer falschen Interpretation der Fälle beruhen, auf einem falschen Aspekt, unter dem jeweils das Verhältnis gesehen wird, in dem die einzelne Situation zu unserer gegenwärtigen Wirklichkeit steht. Meine Absicht im Folgenden ist der Versuch, das zu begründen und einen möglicherweise richtigeren Aspekt anzudeuten.
                    </p>
                    </item>
                </list>
            </lem>
            <rdg wit="#b">
                    <list type="numbered" rend="small_letters">
                    <label type="list">(1)</label>
                    <item copyOf="#Liste1"/>
                    <label type="list">(2)</label>
                    <item copyOf="#Liste2"/>
                    <label type="list">(5)</label>
                    <join result="item" scope="branches" target="#Liste5 #Liste6"/>
                </list>
            </rdg>
        </app>
    </body>
};